@@ -37,7 +37,8 @@ import java.util.Set;
 public abstract class JsonRequestHandler {
 
     // Restrictor for restricting operations
-    protected final Restrictor restrictor;
+
+    private final Restrictor restrictor;
 
     protected JsonRequestHandler(Restrictor pRestrictor) {
         restrictor = pRestrictor;
@@ -59,8 +60,9 @@ public abstract class JsonRequestHandler {
      * {@link #doHandleRequest(javax.management.MBeanServerConnection, org.jmx4perl.JmxRequest)}
      * (<code>false</code>) or
      * {@link #doHandleRequest(java.util.Set, org.jmx4perl.JmxRequest)} (<code>true</code>) called.
+     * @param pRequest request to decide on whether to handle all request at once
      */
-    public boolean handleAllServersAtOnce() {
+    public boolean handleAllServersAtOnce(JmxRequest pRequest) {
         return false;
     }
 
@@ -115,7 +117,7 @@ public abstract class JsonRequestHandler {
     /**
      * Override this if you want to have all servers at once for processing the request
      * (like need for merging info as for a <code>list</code> command). This method
-     * is only called when {@link #handleAllServersAtOnce()} returns <code>true</code>
+     * is only called when {@link #handleAllServersAtOnce(JmxRequest)} returns <code>true</code>
      *
      * @param servers all MBeans servers detected
      * @param request request to process
@@ -127,6 +129,14 @@ public abstract class JsonRequestHandler {
         return doHandleRequest(servers,request);
     }
 
+    /**
+     * Default implementation fo handling a request for multiple servers at once. A subclass, which returns,
+     * <code>true</code> on {@link #handleAllServersAtOnce(JmxRequest)}, needs to override this method.
+     *
+     * @param servers all MBean servers found in this JVM
+     * @param request the original request
+     * @return the result of the the request.
+     */
     public Object doHandleRequest(Set<MBeanServerConnection> servers, JmxRequest request)
                 throws InstanceNotFoundException, AttributeNotFoundException, ReflectionException, MBeanException, IOException {
         return null;
@@ -140,4 +150,14 @@ public abstract class JsonRequestHandler {
     public boolean useReturnValueWithPath() {
         return true;
     }
+
+    /**
+     * Get the restrictor which is currently active
+     *
+     * @return restrictor
+     */
+    protected Restrictor getRestrictor() {
+        return restrictor;
+    }
+
 }
