@@ -18,6 +18,7 @@ JMX::Jmx4Perl::J4psh::Shell - Facade to Term::ShellUI
 =cut
 
 my $USE_TERM_SIZE;
+my $USE_SEARCH_PATH;
 BEGIN {
     
     eval {
@@ -26,6 +27,11 @@ BEGIN {
     };
     $USE_TERM_SIZE = $@ ? 0 : 1;
 
+    eval {
+        require "File::SearchPath";
+        File::SearchPath->import('searchpath');
+    };
+    $USE_SEARCH_PATH = $@ ? 0 : 1;      
 }
 
 
@@ -71,23 +77,10 @@ sub color {
     }
 }
 
-
 sub color_theme {
     return shift->_get_set("color_theme",@_);
 }
 
-sub use_color { 
-    my $self = shift;
-    my $use_color = "yes";
-    if (exists $self->{args}->{color}) {
-        $use_color = $self->{args}->{color};
-    } elsif (exists $self->{config}->{use_color}) {
-        $use_color = $self->{config}->{use_color};
-    } 
-    return $use_color =~ /(yes|true|on)$/;
-}
-
-
 sub use_color {
     my $self = shift;
     my $value = shift;
@@ -97,6 +90,7 @@ sub use_color {
     return $self->{use_color};
 }
 
+
 sub _resolve_color {
     my $self = shift;
     my $c = shift;
@@ -129,6 +123,14 @@ sub _init {
     # Init color theme
     $self->_init_theme($config->{theme});
 
+    my $use_color = "yes";
+    if (exists $self->{args}->{color}) {
+        $use_color = $self->{args}->{color};
+    } elsif (exists $self->{config}->{usecolor}) {
+        $use_color = $self->{config}->{usecolor};
+    } 
+    $self->use_color($use_color);
+
     # Force pipe, quit if less than a screen-full.
     my @args = (
                 '-f',  # force, needed for color output
@@ -151,6 +153,27 @@ sub _init {
     } else {
         $ENV{LESS} = join " ",@args;
     }
+    if ($self->{config}->{pager}) {
+        $ENV{PAGER} = $self->{config}->{pager};
+    } elsif (!$ENV{PAGER}) {
+        # Try to find a suitable pager
+        if ($USE_SEARCH_PATH) {
+            for my $p (qw(less more)) {
+                my $pager = searchpath($p, env => 'PATH', exe => 1 );
+                if ($pager) {
+                    $ENV{PAGER} = $pager;
+                    last;
+                }
+            }
+        }
+        # No searching available, we rely on Term::Clue for finding the proper
+        # pager.
+    } 
+      
+    if ($ENV{PAGER} && $ENV{PAGER} =~ /more$/) {
+        # If we are using "more", disable coloring
+        $self->use_color("no");
+    }
 }
 
 sub default_theme {
