@@ -77,7 +77,6 @@ sub get_requests {
     } else {
         push @requests,JMX::Jmx4Perl::Request->new(EXEC,$self->_prepare_exec_args($jmx,@$args));
     }
-
     if ($self->base) {
         if (!looks_like_number($self->base)) {
             # It looks like a number, so we will use the base literally
@@ -345,7 +344,10 @@ sub _verify_response {
     my ($self,$req,$resp) = @_;
     my $np = $self->{np};
     if ($resp->is_error) {
-        $np->nagios_die("Error: ".$resp->status." ".$resp->error_text.($resp->stacktrace ? "\nStacktrace:\n".$resp->stacktrace : ""));
+        my $stacktrace = $resp->stacktrace;
+        my $extra = "";
+        $extra = ref($stacktrace) eq "ARRAY" ? join "\n",@$stacktrace : $stacktrace if $stacktrace;
+        $np->nagios_die("Error: ".$resp->status." ".$resp->error_text.$extra);
     }
     
     if (!$req->is_mbean_pattern && (ref($resp->value) && !$self->string)) { 
@@ -420,11 +422,19 @@ sub _prepare_exec_args {
 sub _split_attr_spec {
     my $self = shift;
     my $name = shift;
-
-    return &parse_line('/',0,$name);
+    my @ret = ();
+    # Text:ParseWords is used for split on "/" taking into account
+    # quoting and escaping
+    for my $p (&parse_line("/",1,$name)) {
+        # We need to 'unescape' things ourselves
+        # since we want quotes to remain in the names (using '0'
+        # above would kill those quotes, too). 
+        $p =~ s|\\(.)|$1|sg;
+        push @ret,$p;
+    }    
+    return @ret;
 }
 
-
 sub _check_threshhold {
     my $self = shift;
     my $value = shift;
@@ -603,7 +613,7 @@ my $CHECK_CONFIG_KEYS = {
                          "label" => "label",
                          # New:
                          "value" => "value",
-                         "null" => "null"
+                         "null" => "null",
                         };
 
 
