@@ -1,8 +1,6 @@
 package ProductTest::Test2Handler;
 
-use JMX::Jmx4Perl::Product::BaseHandler;
-use vars qw(@ISA);
-@ISA = qw(JMX::Jmx4Perl::Product::BaseHandler);
+use base qw(JMX::Jmx4Perl::Product::BaseHandler);
 
 sub id { return "Test2" };
 
